==> gradle-src-8.10.2-1-any.pkg.tar.zst: usr/share/java/gradle/src/dependency-management/org/gradle/internal/component/resolution/failure/interfaces/VariantSelectionByAttributesFailure.java <==
/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.component.resolution.failure.interfaces;

import org.gradle.api.internal.attributes.ImmutableAttributes;
import org.gradle.internal.component.external.model.ImmutableCapabilities;

/**
 * Represents a specific type of {@link VariantSelectionFailure} where the failure occurred
 * due to a failure to select a variant of a component based on the requested attributes.
 */
public interface VariantSelectionByAttributesFailure extends VariantSelectionFailure {
    /**
     * Gets the attributes that were used to attempt to select a variant.
     * <p>
     * This includes the original request attributes from the root variant and any additional attributes added
     * to the specific dependency used to select the {@link #getTargetComponent()} represented by this edge in the graph.
     *
     * @return the requested attributes that were used to attempt to select a variant
     */
    ImmutableAttributes getRequestedAttributes();

    /**
     * Gets the capabilities requested on the dependency that selected the {@link #getTargetComponent()}
     * represented by this edge in the graph.
     *
     * @return the capabilities used to select the component in the graph failing to select a variant
     */
    ImmutableCapabilities getRequestedCapabilities();
}

==> gradle-src-8.12-1-any.pkg.tar.zst: usr/share/java/gradle/src/dependency-management/org/gradle/internal/component/resolution/failure/interfaces/VariantSelectionByAttributesFailure.java <==
/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.component.resolution.failure.interfaces;

import org.gradle.api.artifacts.capability.CapabilitySelector;
import org.gradle.api.internal.attributes.ImmutableAttributes;

import java.util.Set;

/**
 * Represents a specific type of {@link VariantSelectionFailure} where the failure occurred
 * due to a failure to select a variant of a component based on the requested attributes.
 */
public interface VariantSelectionByAttributesFailure extends VariantSelectionFailure {
    /**
     * Gets the attributes that were used to attempt to select a variant.
     * <p>
     * This includes the original request attributes from the root variant and any additional attributes added
     * to the specific dependency used to select the {@link #getTargetComponent()} represented by this edge in the graph.
     *
     * @return the requested attributes that were used to attempt to select a variant
     */
    ImmutableAttributes getRequestedAttributes();

    /**
     * Gets the capabilities requested on the dependency that selected the {@link #getTargetComponent()}
     * represented by this edge in the graph.
     *
     * @return the capabilities selectors used to select a variant
     */
    Set<CapabilitySelector> getCapabilitySelectors();
}
